==> gravitino-0.7.0-incubating-src.tar.gz: gravitino-0.7.0-incubating-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergUpdateTableFailureEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.gravitino.iceberg.service.IcebergRestUtils;
import org.apache.iceberg.rest.requests.UpdateTableRequest;

/** Represent a failure event when updating Iceberg table failed. */
@DeveloperApi
public class IcebergUpdateTableFailureEvent extends IcebergTableFailureEvent {
  private UpdateTableRequest updateTableRequest;

  public IcebergUpdateTableFailureEvent(
      String user,
      NameIdentifier nameIdentifier,
      UpdateTableRequest updateTableRequest,
      Exception e) {
    super(user, nameIdentifier, e);
    this.updateTableRequest =
        IcebergRestUtils.cloneIcebergRESTObject(updateTableRequest, UpdateTableRequest.class);
  }

  public UpdateTableRequest updateTableRequest() {
    return updateTableRequest;
  }
}

==> gravitino-0.8.1-incubating-src.tar.gz: gravitino-0.8.1-incubating-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergUpdateTableFailureEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.gravitino.iceberg.service.IcebergRestUtils;
import org.apache.iceberg.rest.requests.UpdateTableRequest;

/** Represent a failure event when updating Iceberg table failed. */
@DeveloperApi
public class IcebergUpdateTableFailureEvent extends IcebergTableFailureEvent {
  private final UpdateTableRequest updateTableRequest;

  public IcebergUpdateTableFailureEvent(
      IcebergRequestContext icebergRequestContext,
      NameIdentifier nameIdentifier,
      UpdateTableRequest updateTableRequest,
      Exception e) {
    super(icebergRequestContext, nameIdentifier, e);
    this.updateTableRequest =
        IcebergRestUtils.cloneIcebergRESTObject(updateTableRequest, UpdateTableRequest.class);
  }

  public UpdateTableRequest updateTableRequest() {
    return updateTableRequest;
  }

  @Override
  public OperationType operationType() {
    return OperationType.ALTER_TABLE;
  }
}
